# This is the upstream-preferred name of the project
Name:           cAudio
Version:        2.2.0
Release:        2%{?dist}
Summary:        3D Audio Engine Based on Openal

License:        zlib
URL:            https://github.com/R4stl1n/cAudio/
Source0:        https://github.com/R4stl1n/cAudio/archive/v%{version}.tar.gz

# CMake files for ogg, vorbis
# Files are drawn from allegro5, under Giftware license.
Source1:        https://raw.githubusercontent.com/liballeg/allegro5/master/cmake/FindOgg.cmake
Source2:        https://raw.githubusercontent.com/liballeg/allegro5/master/cmake/FindVorbis.cmake

# Patch to unbundle ogg, vorbis
# Version of this was sent upstream: https://github.com/R4stl1n/cAudio/pull/41
Patch0:         https://tc01.fedorapeople.org/cAudio/cAudio-unbundle-ogg-vorbis.patch

# Patch to fix -fpermissive errors on EAX plugin.
Patch1:         https://tc01.fedorapeople.org/cAudio/cAudio-fpermissive.patch

# Patch for downstream soname versioning
# Request for this was sent upstream: https://github.com/R4stl1n/cAudio/issues/40
# After a week with no response, I began doing it downstream in accordance with our
# guidelines: https://fedoraproject.org/wiki/Packaging:Guidelines#Downstream_.so_name_versioning
Patch2:         https://tc01.fedorapeople.org/cAudio/cAudio-downstream-soname-versioning.patch

# We need cmake and a compiler, obviously.
BuildRequires:  gcc-c++, cmake

BuildRequires:  libogg-devel, libvorbis-devel, openal-soft-devel

BuildRequires:  doxygen

%description
cAudio is a 3D audio engine based on OpenAL.

# this subpackage maybe should be merged into -devel or -doc

%package examples

Summary:       Examples for cAudio
Requires:      %{name}%{?_isa} = %{version}-%{release}

%description examples

A set of examples for cAudio.

%package devel

Summary:       Development headers for cAudio
Requires:      %{name}%{_isa} = %{version}-%{release}

%description devel

Development files and library headers for cAudio.

%package doc

Summary:       API documentation for cAudio
Requires:      %{name}%{_isa} = %{version}-%{release}

BuildArch:     noarch

%description doc

API documentation for cAudio, generated using doxygen.

%prep
%autosetup -p1

# Remove bundled dependencies
rm -rf Dependencies*
cp %SOURCE1 %SOURCE2 CMake/Packages/

# Set /lib manually because this software has interesting ideas about how to use cmake
sed 's,/lib,/%{_lib},g' -i CMakeLists.txt
sed 's,LIBRARY DESTINATION lib,LIBRARY DESTINATION %{_lib},g' -i CMake/InstallDependencies.cmake

%build
mkdir build
cd build
# Only build the EAX_PLUGIN.
# There is a MPEG decoder plugin that uses code derived from ffmpeg; this can't be built in Fedora.
# There are also C# bindings. They do not compile: https://github.com/R4stl1n/cAudio/issues/42
%cmake .. -DCAUDIO_BUILD_EAX_PLUGIN=TRUE

make %{?_smp_mflags}

cd ../
doxygen

%install
cd build
make install DESTDIR=%{buildroot}

# Install the documentation
mkdir -p %{buildroot}%{_docdir}/%{name}/
cp -a ../README.md %{buildroot}%{_docdir}/%{name}/
cp -ra ../Documentation/html %{buildroot}%{_docdir}/%{name}/

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
# XXX: not soname'd by upstream
%{_libdir}/libcAudio.so.0.1
%{_libdir}/libEAXLegacyPreset.so.0.1
%license License.txt
%doc %{_docdir}/%{name}/README.md

%files examples
%{_bindir}/Tutorial*

%files devel
%{_libdir}/libcAudio.so
%{_libdir}/libEAXLegacyPreset.so
%{_includedir}/cAudio

%files doc
%doc %{_docdir}/%{name}/html

%changelog
* Thu Jul 28 2016 Ben Rosser <rosser.bjr@gmail.com> 2.2.0-2
- Fix build of libEAXLegacyPreset plugin.
- Version both libcAudio.so and libEAXLegacyPreset.so downstream.
- Create doc subpackage for the cAudio documentation.

* Thu Jul 21 2016 Ben Rosser <rosser.bjr@gmail.com> 2.2.0-1
- Initial package.
- Unbundled libogg and libvorbis.
